From: Raphaƫl Gertz <git@rapsys.eu>
Date: Wed, 8 Sep 2021 16:33:51 +0000 (+0200)
Subject: Fix encodePassword renaming in hashPassword
X-Git-Tag: 0.2.0~11
X-Git-Url: https://git.rapsys.eu/userbundle/commitdiff_plain/21d5ff1e87df6e791d81b8b41e6030f28476cf7d

Fix encodePassword renaming in hashPassword
---

diff --git a/Controller/DefaultController.php b/Controller/DefaultController.php
index 32ab736..6fed8f5 100644
--- a/Controller/DefaultController.php
+++ b/Controller/DefaultController.php
@@ -148,7 +148,7 @@ class DefaultController extends AbstractController {
 					$data = $reset->getData();
 
 					//Set password
-					$data->setPassword($this->hasher->encodePassword($data, $data->getPassword()));
+					$data->setPassword($this->hasher->hashPassword($data, $data->getPassword()));
 
 					//Queue snippet save
 					$this->manager->persist($data);
@@ -472,14 +472,14 @@ class DefaultController extends AbstractController {
 				//Set data
 				$data = $form->getData();
 
-				//Set encoded password
-				$encoded = $this->hasher->encodePassword($user, $user->getPassword());
+				//Set hashed password
+				$hashed = $this->hasher->hashPassword($user, $user->getPassword());
 
 				//Update pass
-				$pass = $this->slugger->hash($encoded);
+				$pass = $this->slugger->hash($hashed);
 
 				//Set user password
-				$user->setPassword($encoded);
+				$user->setPassword($hashed);
 
 				//Persist user
 				$this->manager->persist($user);
@@ -741,7 +741,7 @@ class DefaultController extends AbstractController {
 				$registerMail =& $this->config['register']['mail'];
 
 				//Set password
-				$user->setPassword($this->hasher->encodePassword($user, $user->getPassword()));
+				$user->setPassword($this->hasher->hashPassword($user, $user->getPassword()));
 
 				//Persist user
 				$this->manager->persist($user);